%
%               FILE DESCRIBING THE GODDARD ISCCP D2 CLOUD TOP TEMPERATURE DATA SET.

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';
% FUNCTIONS -- OPTIONAL
Cat_m_File = 'ffcsquery';

% VARIABLES -- OPTIONAL
CatalogServer = 'http://daac.gsfc.nasa.gov/daac-bin/nph-ff/DODS/catalog/isccp_d2-cat.dat';

axes_order = [2 1 0 0];

% VARIABLES -- REQUIRED
LonRange = [-180 180];
LatRange = [90 -90];
TimeRange = [1986 1994];
DepthRange = [0 0];
Resolution = 111.0;

DataName = 'Cloud Top Temperature - ISCCP D2 - GSFC';
SelectableVariables = str2mat('Cloud_Top_Temp');
DodsName = 'cldtmp';

Additional_FileServer_Constraints = 'type&type="cldtmp"';
% note: DataNull is applied *before* scaling
DataNull = cell(size(DodsName,1)+4,1);
[DataNull(:)] = deal({nan}); 
[DataNull(5:length(DataNull))] = deal({-999.9899902343750});
DataScale = [NaN NaN; ...
             NaN NaN; ...
             NaN NaN; ...
             NaN NaN; ...
             -273.16 1.0];

Acknowledge = sprintf('%s\n', ...
[ ' The authors wish to thank William B. Rossow, and the Goddard Institute for ',...
 'Space Studies (GISS),New York, NY, USA, for the production of this data set, and ',...
 'the Distributed Active Archive Center (Code 902) at the Goddard Space Flight Center, ',...
 'Greenbelt, MD, 20771, for putting these data in their present format and distributing ',...
 'them. These distribution activities were sponsored by NASAs Mission to Planet Earth program.']);

% COMMENTS
Comment1 = sprintf('%s\n', ...
'                 ISCCP D2 Cloud Data Product (C2 is an older version of this dataset)', ...
' ', ...
'    A combination of satellite-measured radiances, TOVS atmospheric temperature/humidity and ',...
' ice/snow data are used by ISCCP to produce a global dataset on cloud and surface variables. ',...
' An overview of the Project and the data products is given in Rossow and Schiffer (1991); the ',...
' algorithm and its effectiveness are described by Rossow and Garder (1993a&b) while Rossow et ',...
' al. (1993) compare the resulting products to other cloud climatologies. The ISCCP D-series, ',...
' which is described in this readme and more extensively in Rossow et al. (1996), is a revised ',...
' version of the C-series dataset. The ISCCP D2-series products are gridded data averaged over ',...
' each month. These data set(presently covering the period 1986-1987 & 1989-1992) are originally ',...
' produced on an equal area map grids which has a constant 2.5 degree latitude increments and ',...
' varaiable longitude increments ranging from 2.5 degree at the equator to 120 degree at the pole. ',...
' The Goddard DAAC has regridded a subset (36 out of the original 130 parameters) of these dataset ',...
' to 1x1 degree equal angle grid for inclusion in the Interdisciplinary data collection.');

Comment2 = sprintf('%s\n', ...
' ',...
'    The original ISCCP D1 (daily) and D2 (monthly mean) products were calculated on an ',...
' approximately equal area world grid (280x280 km^2) which is equivalent to a 2.5x2.5 degree ',...
' latitude-longitude grid at the equator. The latitude band widths were fixed to 2.5 degree ',...
' and grid size along the longitude was varied to provide an integer number of cells in a ',...
' latitude zone and grid cell area as close to an equatorial grid cell as possible. Map grids ',...
' started from south pole to north pole. In each latitude zone, all longitudes were indexed in ',...
' order from the Greenwich meridian eastward (0 - 360 degree) before going to the next latitude ',...
' zone. Here we have interpolated a subset (36 out of the original 130 parameters) of the equal ',...
' area monthly mean products to a 1x1 degree grid for easy comparison to the other ',...
		   ' Interdisciplinary Data Collection products.');

Comment3 = sprintf('%s\n', ...
' ',...
'                 Variables in the Data Set', ...
' ',...
'  cldfrc  -  mean cloud fraction                                      -   0.5 to 100 percent',...
'  cldprs  -  mean cloud top pressure                                  -  35 to 985 millibars',...
'  cldtau  -  mean cloud optical thickness                             -   0.09 to 50 dimensionless',...
'  cldtmp  -  mean cloud top temperature                               - -93 to 47 C (K in the original data)',...
'  srfref  -  mean clear sky surface reflectance                       -   0 to 1.1 fraction',...
'  srftmp  -  mean clear sky surface temperature                       - -74 to 52 C (K in the original data)',...
'  cldwpt  -  mean cloud water path                                    -  0 - 400 g/m^2',...
'  irlfrc  -  infrared cloud fraction, for low-level clouds            -  0 - 93 percent',...
'  irlprs  -  infrared cloud top pressure, for low-level clouds        -  550 - 1000 millibars',...
'  irltmp  -  infrared cloud top temperature, for low-level clouds     -  225 - 315 Kelvin',...
'  irmfrc  -  infrared cloud fraction, for mid-level clouds            -  0 - 82 percent',...
'  irmprs  -  infrared cloud top pressure, for mid-level clouds        -  435 - 680 millibars',...
'  irmtmp  -  infrared cloud top temperature, for mid-level clouds     -  211 - 287 Kelvin',...
'  irhfrc  -  infrared cloud fraction, for high-level clouds           -  0 - 84 percent',...
'  irhprs  -  mean infrared cloud top pressure, for high-level clouds  -  20 - 495 millibars',...
'  irhtmp  -  infrared cloud top temperature, for high-level clouds    -  180 - 264 Kelvin',...
'  clfrc  -  cumulus (liquid) low-level cloud fraction                 -  0 - 80 percent',...
'  sclfrc  -  stratocumulus (liquid)low-level cloud fraction           -  0 - 88 percent ',...
'  slfrc  -  stratus (liquid)low-level cloud fraction                  -  0 - 50 percent',...
'  cifrc  -  cumulus (ice)low-level cloud fraction                     -  0 - 72 percent ',...
'  scifrc  -  stratocumulus (ice)low-level cloud fraction              -  0 - 91 percent ',...
'  sifrc  -  stratus (ice) cloud low-level fraction                    -  0 - 50 percent ',...
'  aclfrc  -  altocumulus (liquid)mid-level cloud fraction             -  0 - 38 percent ',...
'  aslfrc  -  altostratus (liquid)mid-level cloud fraction             -  0 - 62 percent ',...
'  nslfrc  -  nimbostratus (liquid)mid-level cloud fraction            -  0 - 75 percent ',...
'  acifrc  -  altocumulus (ice)mid-level cloud fraction                -  0 - 95 percent ',...
'  asifrc  -  altostratus (ice)mid-level cloud fraction                -  0 - 100 percent ',...
'  nsifrc  -  mean nimbostratus (ice)mid-level cloud fraction          -  0 - 50 percent ',...
'  crfrc  -  mean cirrus high-level cloud fraction                     -  0 - 100 percent',...
'  crsfrc  -  mean cirrostratus high-level cloud fraction              -  0 - 77 percent ',...
'  dcfrc  -  mean deep convective high-level cloud fraction            -  0 - 62 percent ',...
'  iscvr  -  mean ice/snow cover                                       -  0 - 100 percent ',...
'  tvprs  -  TOVS mean surface pressure                                -  475 - 1000 millibars ',...
'  tvtmp  -  TOVS mean near-surface air temperature                    -  216 - 322 kelvin ',...
'  tvprw1  -  TOVS mean precipitable water for 1000 - 680 mb           -  0 - 5 cm',...
'  tvprw6  -  TOVS mean precipitable water for 680 - 310 mb            -  0.03 - 2.0 cm ');

Comment4 = sprintf('%s\n', ...
' ', ...
'    Because of the way these data are organized in the archive, they are ',...
'included here as separate data sets, one for each variable. They are however ',...
'all derived from the same source and can be easily combined by selecting a ',...
'a region and a time range and a data set and then requesting the data for ',...
'that data set, then requesting a second data set and requesting the corresponding ',...
'data, etc. ',...
' ', ...
'   For more information see: ', ...
'http://daac.gsfc.nasa.gov/CAMPAIGN_DOCS/FTP_SITE/INT_DIS/readmes/isccp_d2.html#200');

Comment5 = sprintf('%s\n', ...
' ',...
'                  REFERENCES',...
' ',...
'Rossow, W. B., and R. A. Schiffer, 1991. ISCCP cloud data products, ',...
'   Bull. Amer. Meteor. Soc., 72:2-20. ',...
' ',...
'Rossow, W. B., and L. C. Garder, 1993a. Cloud detection using satellite',...
'   measurements of infrared and visible radiances for ISCCP, J. Climate, ',...
'   6: 2341-2369. ',...
' ',...
'Rossow, W. B., and L. C. Garder, 1993b. Validation of ISCCP cloud detection, ',...
'   J. Climate, 6: 2370-2393. ',...
' ',...
'Rossow, W. B., A. W. Walker, and L. C. Garder, 1993. Comparison of ISCCP ',...
'   and other cloud amounts, J. Climate, 6:2394-2418.',...
' ',...
'Rossow, W. B., A. W. Walker, D. E. Beuschel, and M. D. Roiter, 1996. ',...
'   International Satellite Cloud Climatology Project (ISCCP): documentation ',...
'   of new cloud datasets, 115 pages, available on internet at: ',...
'   http://isccp.giss.nasa.gov/documents.html');

Comments = [Comment1 Comment2 Comment3 Comment4 Comment5];

