%
%               FILE DESCRIBING THE JPL MODIS DAILY TERRA SST QUALITY DATA SET (MO04QDN1 and MO04QDD1)

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';
% FUNCTIONS -- OPTIONAL
Cat_m_File = 'ffcsquery';

% VARIABLES -- OPTIONAL
CatalogServer = 'http://dods.jpl.nasa.gov/dods-bin/nph-dods/catalogs/modis/L3/daily/04km/daily-04km-Quality.dat';
Additional_FileServer_Constraints = 'platform&platform="terra"';

axes_order = [2 1 0 0];

% VARIABLES -- REQUIRED
LonRange = [-180 180];
LatRange = [90 -90];
TimeRange = [2000+1*30/365+24/365 2005];
DepthRange = [0 0];
Resolution = 4.9;

DataName = 'TERRA Daily SST Quality (MO04QDD1 and MO04QDN1 - JPL';
SelectableVariables = str2mat('Sea_Temp_Quality');
DodsName = 'sst_qual_b';

DataNull = cell(size(DodsName,1)+4,1);
[DataNull(:)] = deal({nan}); 
DataNull(5) = {0};

% COMMENTS
Comments = sprintf('%s\n', ...
'                                     TERRA Daily SST Quality (MO04QDD1 and MO04QDN1)',...
' ',...
' Primary site: Goddard Space Flight Center',...
'  Mirror site: Jet Propulsion Laboratory',...
' ',...
' Quality fields for the Terra 4.88 km SST fields (MO04MD). Two fields per day, one for ascending passes ',...
' and one for descending passes.',...
' ',...
'            GENERAL DESCRIPTION',...
' ',...
'    SST derived from the Moderate-resolution Imaging Spectroradiometer (MODIS) instruments aboard the NASA ',...
' Terra and Aqua satellites represent a new milestone in high sensitivity thermal infrared remote sensing. Data ',...
' are currently available globally at 4 km, 36 km and 1 degree resolutions with daily, weekly and monthly time ',...
' intervals in HDF-EOS files. These data are the latest science quality Level 3 files processed by the Modis ',...
' Adaptive Processing System (MODAPS) and distributed by the Goddard Distributed Active Archive Center (GDAAC) ',...
' located at the NASA Goddard Space Flight Center. PO.DAAC is acting as a mirror site for Level 3 MODIS ocean ',...
' SST products.',...   
' ',...
'          Quality Levels (from http://modis-ocean.gsfc.nasa.gov/qa/L2QLflags.V4.html)',...
'  NOTE: Values in the MOD28L2 "quality" SDS are of type BYTE. Bits 1-2 are the ',...
'       least significant bit pair; bits 7-8 are the most significant bit pair.',...
' ',...
' Bit    Description',...
'_____  ____________________________________________________________________________',...
' 1-2     Mandatory Quality for SST products ',...
'         0 = good, if common flags are clear, input radiance flags are clear, and',...
'             product-specific L2_flags 9,11-16 are clear ',...
'         1 = questionable, large zenith angle, bad ancillary or flags 3,10-11 ',...
'         2 = sun glint or channel uniformity bad contaminated ',...
'         3 = if any input radiances are negative and not saturated, or Atmospheric ',...
'             Correction failed, or Land',...
'____________________________________________________________________________________',...
' 3-4    Mandatory Quality for SST4 products ',...
'        0 = good, if common flags are ok, inputs, both sat zenith tests, both sst4-sst,',...
'            BT22-BT23-ref, both uniformity, brights, and reynolds(optional) ',...
'        1 = questionable, if any of: if sst4-sst test2 , sat zenith test 2, or unif test2 ',...
'        2 = if sst4-sst test 1, sat zenith angle test 1, or uniformity test1 ',...
'        3 = if any input radiances are negative and not saturated, BT22-BT23-ref out of',...
'            range, brights outside (-4..33)',...
'____________________________________________________________________________________',...
' 5-8   Spare',...
' ',...
' See the MODIS Ocean Data Processing site for a general discussion of the processing:',...
'     http://picasso.oce.orst.edu/ORSOO/MODIS/code/',...
' ',...
' For a description of the processing algorithms used see: http://modis.gsfc.nasa.gov/data/atbd/atbd_mod25.pdf',...
' ',...
' The JPL site for these data is: http://podaac.jpl.nasa.gov/modis/');

