% apply_sst_quality - This routine acquires the quality flags for the
%                     specified MODIS SST fields and creates new fields
%                     selecting only the best data.
%
% Input - range of request responses
% Output - new fields prefixed with Q 
%

firstR = input('Enter the R number at which processing will begin: ');
lastR = input('Enter the R number at which processing will end: ');
nPlot = input('Enter do you want to plot the fields when done (y/n)? ','s');
nPlot = lower(nPlot);

for iR=firstR:lastR

   eval(['temp_URL = R' num2str(iR) '_URL;'])
   eval(['Q' num2str(iR) '_Sea_Temp = R' num2str(iR) '_Sea_Temp;'])

   % Need to get the URL for the quality field. First find the date and time 
   % of the SST field. Then get quality URL for the same time. Get platform first.

   Platform_start = findstr(temp_URL, 'modis/data/') + 11;
   if isempty(Platform_start)
     disp('*********************************')
     disp(' ')
     disp('Could not find the satellite name in the base URL')
     disp(' ')
     disp('*********************************')
     return
   end
   Platform_end = findstr(temp_URL(Platform_start:Platform_start+10),'/');
   if isempty(Platform_end)
     disp('*********************************')
     disp(' ')
     disp('Could not find the satellite name in the base URL')
     disp(' ')
     disp('*********************************')
     return
   end
   Platform = temp_URL(Platform_start:Platform_start+Platform_end-2);

   % Now get year and day.

   nYear = findstr(temp_URL, '04km') + 5;
   if isempty(nYear)
     disp('*********************************')
     disp(' ')
     disp('Could not find the year or day corresponding to the satellite pass in the base URL')
     disp(' ')
     disp('*********************************')
     return
   end
   Year = temp_URL(nYear:nYear+3);
   Day = temp_URL(nYear+5:nYear+7);

   % Finally get the actual URL so that we can get the hour from the catalog server.

   nName = findstr(temp_URL, '04M') - 2;
   if isempty(nName)
     disp('*********************************')
     disp(' ')
     disp('Could not find the name of the file corresponding to the satellite pass in the base URL')
     disp(' ')
     disp('*********************************')
     return
   end
   nConstraint = nName + findstr(temp_URL(nName:length(temp_URL)),'?') - 2;
   if isempty(nConstraint)
     disp('*********************************')
     disp(' ')
     disp('Could not find the constraint corresponding to the satellite pass in the base URL')
     disp(' ')
     disp('*********************************')
     return
   end
   Name = temp_URL(nName:nConstraint);

   % Finally we need to determine if it is a day or night pass to get the hour.
   nHour = findstr(temp_URL, '04M') + 4;
   if isempty(nHour)
     disp('*********************************')
     disp(' ')
     disp('Could not find the hour of the file corresponding to the satellite pass in the base URL')
     disp(' ')
     disp('*********************************')
     return
   end
   if temp_URL(nHour) == 'D'
      Hour = 12;
   elseif temp_URL(nHour) == 'N'
      Hour = 0;
   else
     disp('*********************************')
     disp(' ')
     disp('Could not determine if this is a day or night pass.')
     disp(' ')
     disp('*********************************')
     return
   end

   % OK, now we have the day and hour make a request for the URLs for the quality fields.

   BaseURL = 'http://dods.jpl.nasa.gov/dods-bin/nph-dods/catalogs/modis/L3/daily/04km/daily-04km-Quality.dat';
   Constraint = ['?DODS_URL&platform="' Platform '"&date_time("' Year '/' Day, ':' num2str(Hour) '")'];
   eval(['loaddods(''' BaseURL Constraint ''')'])

   % Generate URL for quality field. 
   eval(['loaddods(''' DODS_URL '?sst_qual_b' temp_URL(nConstraint+10:length(temp_URL)) ''')'])

   % Find all low quality pixels and set to NAN in downloaded data.

   nn = find(sst_qual_b(:) > 0);
   eval(['Q' num2str(iR) '_Sea_Temp(nn) = nan;'])

   if nPlot == 'y'
      eval(['figure;imagesc(R' num2str(iR) '_Longitude,R' num2str(iR) '_Latitude,Q' num2str(iR) ...
	 '_Sea_Temp);set(gca,''ydir'',''normal'')'])
   end
end
clear nn Constraint1 Constraint2 BaseURL iHour ihr Name nName nConstraint Year Day nYear
clear Platform_start Platform_end Platform iR firstR lastR DODS_URL year month day hour temp_URL
clear sst_qual_b Constraint nPlot nHour Hour
