function [list] = epstruct(topstruct, topstructname)

% EPSTRUCT  A NVODS Matlab GUI helper function.
% expand struct hierarchy into a flat list
%
% Usage:  [list] = epstruct(struct, 'structname')
%
% ex, for a struct a
%      a == Level_0: [1x1 struct];
%      a.Level_0 == Level_1: [1x1 struct];
%                   x1: some_value;
%                   x2: some_value;
%      a.Level_0.Level_1 == Level_2: [1x1 struct];
%                           x1: some_value;
%      a.Level_0.Level_1.Level_2 == x1: some_value;
%      
%    list = epstruct(a, 'a');
%    returns list = a.Level_0.x1
%                   a.Level_0.x2
%                   a.Level_0.Level_1.x1
%                   a.Level_0.Level_1.Level_2.x1
%

% The old code was rather horrendous.  Dbyrne replaced it all with
% something cleaner, below, 2002/10/07.

% Note that all of the structure names are also saved in
% "structnames".  These could also be returned if needed.

topstructname = 'topstruct';
structnames = {topstructname};
names = fieldnames(eval(topstructname));

finalfields = [];
j = 1;
while j <= size(structnames,1)
  for i = 1:size(names,1)
    if isstruct(eval([structnames{j} '.' names{i}]))
      structnames = [structnames(:); {[structnames{j} '.' names{i}]}];
    else
      finalfields = [finalfields; {[structnames{j} '.' names{i}]}];
    end
  end
  j = j+1;
  if j <= size(structnames,1)
    names = fieldnames(eval(structnames{j}));
  end
end
list = strrep(finalfields,'topstruct','DAS');

% remove 'Global_Attributes' -- 2005/05/06
num_elements = size(list,1);
k = [];
for i = 1:num_elements
  nn = strfind(list{i}, 'Global_Attributes');
  if isempty(nn)
    k = [k i];
  end
end
list = list(k);

% $Id: epstruct.m,v 1.10 2004/05/07 14:23:50 dbyrne Exp $
% klee 07/2000
