% find the longitude or x-map name
mapnames = axnames;
keep = ones(size(mapnames));
for i = 1:size(mapnames,1)
  str = lower(mapnames{i});
  % added loop and reversed order of search so that search will
  % find any das name that starts with any of the strings in X_Names
  for ipcc = 1:length(X_Names)
    if strncmp(X_Names(ipcc), str, length(X_Names{ipcc}))
      xmap = mapnames{i};
      keep(i) = 0;
      break
    end
  end
  if ~keep(i)
    % we've already found a map
    break
  end
end
    
% find the latitude or y-map name
mapnames = mapnames(find(keep));
keep = ones(size(mapnames));
if ~isempty(mapnames)
  for i = 1:size(mapnames,1)
    str = lower(mapnames{i});
    % added loop and reversed order of search so that search will
    % find any das name that starts with any of the strings in X_Names
    for ipcc = 1:length(Y_Names)
      if strncmp(Y_Names(ipcc), str, length(Y_Names{ipcc}))
	ymap = mapnames{i};
	keep(i) = 0;
	break
      end
    end
    if ~keep(i)
      % we've already found a map
      break
    end
  end
end
    
% find the depth/elevation map (z-map)
mapnames = mapnames(find(keep));
keep = ones(size(mapnames));
if ~isempty(mapnames)
  % First look for special names that suggest an
  % atmospheric variable (positive up).
  for i = 1:size(mapnames,1)
    str = lower(mapnames{i});
    for j = 1:size(A_Names)
      if instr(A_Names{j}, str)
	zmap = mapnames{i};
	keep(i) = 0;
	reversedepth = 1;
	break
      end
    end
    if ~keep(i)
      % we've already found a map
      break
    end
  end
  % now look for depth names
  if isempty(zmap)
    for i = 1:size(mapnames,1)
      str = lower(mapnames{i});
      for ipcc = 1:length(Z_Names)
	if strncmp(Z_Names(ipcc), str, length(Z_Names{ipcc}))
	  zmap = mapnames{i};
	  keep(i) = 0;
	  break
	end
      end
      if ~keep(i)
	% we've already found a map
	break
      end
    end
  end
  
end

% find the time axis name (tmap)
mapnames = mapnames(find(keep));
keep = ones(size(mapnames));
% find the time map
if ~isempty(mapnames)
  for i = 1:size(mapnames,1)
    str = lower(mapnames{i});
    for ipcc = 1:length(T_Names)
      if strncmp(T_Names(ipcc), str, length(T_Names{ipcc}))
	tmap = mapnames{i};
	keep(i) = 0;
	break
      end
    end
    if ~keep(i)
      % we've already found a map
      break
    end
  end
end
    
% now get the axes values themselves from the dataset
Constraint = '';
if exist('MapNames') == 1
  for i = 1:ND
    if ~isempty(Constraint), Constraint = [Constraint, ',']; end
    Constraint = [Constraint axnames{i}];
    eval([axnames{i} ' = [];'])
  end
else
  for i = 1:ND
    if ~isempty(Constraint), Constraint = [Constraint, ',']; end
    Constraint = [Constraint field1 '.' axnames{i}];
    eval([axnames{i} ' = [];'])
  end
end

if ~isempty(Constraint)
  url = [server '?' Constraint];
  loaddods('-e', url);
  if ~dods_err
    for i = 1:ND
      if ~isempty(axnames{i})
	ax{i} = eval(axnames{i});
      end
    end
  else
    str = sprintf('%s\n%s', ...
	'Error acquiring data maps from server:', ...
	dods_err_msg);
    dods_err_msg = str;
    return
  end
end

% Get units for the map vectors
if exist('MapNames') == 1
  for i = 1:ND
    eval([ 'f = fieldnames(DAS.' axnames{i} ');']);
    k = strmatch('units', lower(f));
    if ~isempty(k)
      eval([ 'axunits{i} = DAS.' axnames{i} '.' char(f(k)) ';']);
    end
  end
else
  for i = 1:ND
    eval([ 'f = fieldnames(DAS.' newfield1 '.' axnames{i} ');']);
    k = strmatch('units', lower(f));
    if ~isempty(k)
      eval([ 'axunits{i} = DAS.' newfield1 '.' axnames{i} '.' char(f(k)) ';']);
    end
  end
end

% Force gridcat to ignore the axes popup window if axes_order is present. 
% Otherwise query the user.
if exist('axes_order')
  % as a courtesy to programmer, pop up a warning if
  % axes_order appears to be incorrect.
  if ~isempty(xmap)
    geopos(1) = strmatch(xmap,axnames,'exact');
  end
  if ~isempty(ymap)
    geopos(2) = strmatch(ymap,axnames,'exact');
  end
  if ~isempty(zmap)
    geopos(3) = strmatch(zmap,axnames,'exact');
  end
  if ~isempty(tmap)
    geopos(4) = strmatch(tmap,axnames,'exact');
  end
  axes_order = [axes_order zeros(1,4-length(axes_order))];
  if dods_expert_mode
    disp([ 'Array index order being forced by axes_order in ' archive])
    disp([ 'Auto-detected geopos would be: ' num2str(geopos)])
  end
  if ~all(geopos == axes_order) & dods_expert_mode
    dodsmsg([ 'Warning: the axes_order specified in ' archive ...
	  '.m may be incorrect.']);
  end
  % then go ahead any way
  geopos = axes_order;
  % must clear these to prevent future trouble
  if geopos(1) == 0, xmap = ''; end
  if geopos(2) == 0, ymap = ''; end
  if geopos(3) == 0, zmap = ''; end
  if geopos(4) == 0, tmap = ''; end
  % we will have the OPPOSITE problem if there is no identified map
  % where axes_order indicates there should be.
else
  % POPUP WINDOW
  output = dodsaxisdlg('start', axnames, axunits, ax, ...
      'Check Axis Mappings', [{xmap}; {ymap}; {zmap}; {tmap}], ...
      zeros(3,3), 0);
  
  if iscell(output)
    for i = 1:4
      if i == 1, xmap = output{1};
      elseif i == 2, ymap = output{2};
      elseif i == 3, zmap = output{3};
      elseif i == 4, tmap = output{4};
      end
      if ~isempty(output{i})
	j = strmatch(output{i}, axnames,'exact');
	geopos(i) = j;
      else
	geopos(i) = 0;
      end
    end
  else
    % user has cancelled this request
    dods_err = 1;
    dods_err_msg = 'Request cancelled';
    return
  end
    
  % find positions of the axes displayed on the GUI so they
  % can get special treatment.
  if ~isempty(xmap)
    geopos(1) = strmatch(xmap,axnames,'exact');
  end
  if ~isempty(ymap)
    geopos(2) = strmatch(ymap,axnames,'exact');
  end
  if ~isempty(zmap)
    geopos(3) = strmatch(zmap,axnames,'exact');
  end
  if ~isempty(tmap)
    geopos(4) = strmatch(tmap,axnames,'exact');
  end
  if dods_expert_mode
    disp([ 'User-selected geopos: ' num2str(geopos)])
  end
end

% PCC added the following section on 2/2/02 do deal with sign problem in soda
% Depth is a bit special in that sometimes it is positive down and
% sometimes positive up. COARDS compliant data sets often specify
% the direction.  INFORMATION IN THE ARCHIVE.M FILE SHOULD OVERRIDE
% THE DAS IN ALL CASES, INCLUDING THIS ONE. THIS IS INCONSISTENT.
% Fixed logic so this actually does something.  dbyrne 2002/09/27.  
if exist('DepthRange') == 1
  if DepthRange(1) > DepthRange(2)
    reversedepth = 1;
  end
end

if ~isempty(zmap)
  if exist('MapNames') == 1
    eval([ 'f = fieldnames(DAS.' zmap ');']);
  else
    eval([ 'f = fieldnames(DAS.' newfield1 '.' zmap ');']);
  end
  k = strmatch('positive', lower(f));
  if ~isempty(k)
    if exist('MapNames') == 1
      eval([ 'pos_up_down = DAS.' zmap '.' char(f(k)) ';']);
    else
      eval([ 'pos_up_down = DAS.' newfield1 '.' zmap '.' char(f(k)) ';']);
    end
    str_up = 'up';
    str_down = 'down';
    if ~isempty(instr(str_up, lower(pos_up_down)))
      reversedepth = 1;
    elseif ~isempty(instr(str_up, lower(pos_up_down)))
      reversedepth = 0;
    end
  end
end

if reversedepth; ax{geopos(3)} = -ax{geopos(3)}; end

% Independent maps may need to be scaled and
% may have missing/null values.
if exist('MapNames') == 1
  for i = 1:ND
    m = strmatch(axnames{i}, data_name,'exact');
    if ~isempty(data_null{m})
      if any(~isnan(data_null{m}))
	for k = 1:length(data_null{m})
	  j = find(fpcompare(ax{i},data_null{m}(k),16));
	  ax{i}(j) = nan;
	end
      end
    end
    ax{i} = data_scale{m}(1) + ax{i}*data_scale{m}(2);
  end
end
