%
%  File Describing The Goddard Space Flight Center NDVI data set

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';
% FUNCTIONS -- OPTIONAL
Cat_m_File = 'ffcsquery';

% VARIABLES -- OPTIONAL
CatalogServer = 'http://eosdata.gsfc.nasa.gov/daac-bin/nph-ff/DODS/catalog/avhrr_ndvi-cat.dat';
Nlon = 360;
Nlat = 180;

% VARIABLES -- REQUIRED
LonRange = [-180.0 180.0];
LatRange = [90.0 -90.0];
TimeRange = [1979-45/360 1986+(180+15)/360];
DepthRange = [0 0];
Resolution = 111;

DataName = 'NDVI - Normalized Difference Vegetation Index - GSFC'; 
SelectableVariables = str2mat('NDVI');
DodsName = 'ndvi';

DataNull = cell(size(DodsName,1)+4,1);
[DataNull(:)] = deal({nan}); 
DataNull(5) = {[-99.9990005493164 -9.99899959564209]};
DataScale = [NaN NaN; NaN NaN; NaN NaN; NaN NaN; NaN NaN];

Data_Use_Policy = '';

Acknowledge = sprintf('%s\n%s\n%s\n%s\n%s', ...
   [ 'Dataset_Creator: James, M., J. Townshend'], ...
   [ 'Dataset_Title: NDVI Data from AVHRR Land Pathfinder'],...
   [ 'Dataset_Release_Date: Greenbelt, MD'],...
   [ 'Dataset_Release_Place: NASA/GSFC'],...
   [ 'Online_Resource: http://daac.gsfc.nasa.gov/CAMPAIGN_DOCS/FTP_SITE/INT_DIS/readmes/pal.html ']);

% COMMENTS
Comments1 = sprintf('%s\n', ...
'  This data set is produced as part of the NOAA/NASA Pathfinder AVHRR ',...
'Land program. It contains global monthly composites of the ',...
'Normalized Difference Vegetation Index (NDVI) at 1 degree ',...
'resolution covering the period from July 1981 to September ',...
'1994. This monthly climate data set was recently updated since the ',...
'original data (the 10-day composite) used for generating this ',...
'monthly dataset, was recently reprocessed. The Pathfinder Program ',...
'produces long-term data sets derived from the observations made by ',...
'Advanced Very High Resolution Radiometers (AVHRR) on the ',...
'"afternoon" NOAA operational meteorological satellites (NOAA-7, -9, ',...
'11) and processed in a consistent manner for global change research.');

Comments2 = sprintf('%s\n', ...
' ',...
'  For more information, see the Global Change Master Directory entry for this at',...
'http://gcmd2.gsfc.nasa.gov/cgi-bin/md/zgate?present+27570+Default+10+1+F+1.2.840.10003.5.109.3+CIDC_AVHRR_NDVI');

Comments = [Comments1 Comments2];

