%
%               File Describing The JPL Pathfinder 9km dataset

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';
% FUNCTIONS -- OPTIONAL
Cat_m_File = 'ffcsquery';

% VARIABLES -- OPTIONAL
CatalogServer = 'http://dods.jpl.nasa.gov/cgi-bin/nph-dods/catalogs/pathfinder/daily-09km.dat';

% can either define axis sizes like below or axes_order
Nlon = 4096;
Nlat = 2048;

% VARIABLES -- REQUIRED
LonRange = [-180.0 180.0];
LatRange = [90.0 -90.0];
TimeRange = [1985+3/365 2000];
DepthRange = [0 0];
DepthUnits = '';
Resolution = 9.28;

DataName = 'SST - 9km Pathfinder - JPL'; % Name for this dataset.
% It appears that neither lat not lon variables are returned by the JPL
% Pathfinder data server. The data are not stored in a Grid... jhrg 11/28/97
LongitudeName = '';
LatitudeName = '';
TimeName = '';
DepthName = '';
SelectableVariables = str2mat('Sea_Temp');
DodsName = 'Raster Image #0';

% According to the attributes for this dataset, SST in degrees C = DN * .15 -
% 3. I'm not sure what the various parts of this matrix really do, but this
% seems to where the M and B values are stored for a simple linear scaling.
% jhrg 12/2/97.

% I believe this is correct: dbyrne 98/09/13
DataNull = cell(size(DodsName,1)+4,1);
[DataNull(:)] = deal({nan}); 
DataNull(5) = {0};
DataScale = [NaN NaN; NaN NaN; NaN NaN; NaN NaN; -3.0 0.15];

Data_Use_Policy = '';

Acknowledge = sprintf('%s\n\n%s\n%s\n%s', ...
    [ ' These data are provided on-line by NASA''s Physical ',...
      'Oceanography Data Active Archive Center (PODAAC: ',...
      'http://podaac.jpl.nasa.gov) and were accessed via ',...
      'the National Virtual Ocean Data System (NVODS: ',...
      'http://www.unidata.ucar.edu/packages/dods).'], ...
    [ 'Citations: Brown, J.W., O.B. Brown and R.H. Evans, 1993. ', ...
	  'Calibration of AVHRR infrared channels: a new approach to non-linear ', ...
	  'correction. J. Geophys. Res., 98, (NC10), 18257-18268.'], ...
    [ 'Vazquez, J., A. Van Tran, R. Sumagaysay, E. Smith and M. Hamilton ', ...
      'NOAA/NASA AVHRR Oceans Pathfinder Sea Surface Temperature Data Set ', ...
      'User''s Guide Version 1.2 ', ...
      'http://podaac.jpl.nasa.gov/sstO/usr_gde.htm'],...
    [ 'Vazquez, J., R. M. Sumagaysay, and K. L. Perry ', ...
      'NOAA/NASA AVHRR Oceans Pathfinder Sea Surface Temperature Data Set ', ...
      'User''s Reference Manual Version 4.1 ', ...
      'http://podaac.jpl.nasa.gov/pub/sea_surface_temperature/avhrr/pathfinder/doc/usr_rfman4_1.html']);


% COMMENTS
Comments1 = sprintf('%s\n', ...
    '                     JPL Pathfinder SST Data', ...
    '   ', ...
    'The NOAA/NASA AVHRR Oceans Pathfinder sea surface temperature data', ...
    'are derived from the 5-channel Advanced Very High Resolution', ...
    'Radiometers (AVHRR) on board the NOAA-7, -9, -11 and -14 polar', ...
    'orbiting satellites. Daily and monthly averaged data for both the ', ...
    'ascending pass (daytime) and descending pass (nighttime) are', ...
    'available on equal-angle grids of 4096 pixels/360 degrees (nominally ',...
    'referred to as the 9km resolution), 2048 pixels/360 degrees (nominally',...
    'referred to as the 18km resolution), and 720 pixels/360 degrees', ...
    '(nominally referred to as the 54km resolution or 0.5 degree', ...
    'resolution). Version 3 algorithm data currently exist for the period ',...
    'between January 1991 and September 1994, and Version 1 data exist ', ...
    'between January 1987 and December 1993. Version 4.0 (beta) data exist', ...
    'for 1985-1995. Version 4.1 data exist for 1996 and a quality flag of', ...
    '0-7 is assigned to the SST pixel value. The highest quality has a', ...
    'value of 7 and the lowest has a value of 0. Earlier versions (1,3,4.0)', ...
    'of the data have a quality flag between 0-3 assigned to the SST pixel', ...
    'value. For more details on the assignment of the quality flags see', ...
    'the NOAA/NASA AVHRR Oceans Pathfinder Sea Surface Temperature Data Set', ...
    'User''s Guide URL: http://podaac.jpl.nasa.gov/sstO/usr_gde.htm, and', ...
    'the NOAA/NASA AVHRR Oceans Pathfinder User''s Reference Manual URL: ', ...
    'http://podaac.jpl.nasa.gov/pub/sea_surface_temperature/avhrr/pathfinder/doc/usr_rfman4_1.html');
Comments2 = sprintf('%s\n', ...
'    Spatial coverage: ', ...
'    ', ...
'         90N-90S  1-360E (9.28km res.) ', ...
'    ', ...
'    Temporal coverage: ', ...
'    ', ...
'         January 1985 through December 1995 ', ...
'         Two images per day. ', ...
'    ', ...
'    Levels: ', ...
'    ', ...
'         Surface data.  ', ...         
'    ', ...
'    References: ', ...
'    ', ...
'       Brown, J.W., O.B. Brown and R.H. Evans, 1993.', ...
'       Calibration of AVHRR infrared channels: a new approach to non-linear ', ...
'        correction. J. Geophys. Res., 98, (NC10), 18257-18268.', ...
'    ', ...
'       Vazquez, J., A. Van Tran, R. Sumagaysay, E. Smith and M. Hamilton', ...
'       NOAA/NASA AVHRR Oceans Pathfinder Sea Surface Temperature Data Set', ...
'       User''s Guide Version 1.2', ...
'       "http://podaac.jpl.nasa.gov/sstO/usr_gde.htm" ',...
'    ', ...
'       Vazquez, J., R. M. Sumagaysay, and K. L. Perry', ...
'       NOAA/NASA AVHRR Oceans Pathfinder Sea Surface Temperature Data Set', ...
'       User''s Reference Manual Version 4.1', ...
'       "http://podaac.jpl.nasa.gov/pub/sea_surface_temperature/avhrr/pathfinder/doc/usr_rfman4_1.html"');
Comments3 = sprintf('%s\n', ...
'   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date:1985 ', ...
'         Ending_Date:1995 ', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate:0.0 ', ...
'              East Bounding Coordinate:360.0 ', ...
'              South Bounding Coordinate:-90.00 ', ...
'              North Bounding Coordinate:+90.00 ', ...
'    Units:  Degrees Centigrade ', ...
'    Resolution: .15 deg. C ', ...
'    Accuracy: This is still an "open issue" accoring to the User''s Guide ', ...
'   ', ...
'    Point_of_Contact (Science) = ', ...
'         Address: ', ...
'               Jorge Vazquez ', ...
'               M/S 300-320 ', ...
'               Jet Propulsion Laboratory', ...
'               4800 Oak Grove Drive', ...
'               Pasadena, California 91109', ...
'               USA ', ...
'         Electronic Mail Address:INTERNET > jv@pacific.jpl.nasa.gov', ...
'         Address: ', ...
'               Robert Evans ', ...
'               Rosenstiel School of Marine and Atmospheric Science', ...
'               Unversity of Miami', ...
'               4600 Rickenbacker Causeway', ...
'               Miami, Florida 33149-1098', ...
'               USA ', ...
'         Electronic Mail Address:INTERNET > revans@rsmas.miami.edu', ...
'    Point_of_Contact (Data Provision) = ', ...
'         Address: ', ...
'               Johan Berlin', ...
'               JPL PO.DAAC', ...
'               M/S 300-320', ...
'               Jet Propulsion Laboratory', ...
'               4800 Oak Grove Drive', ...
'               Pasadena, California 91109', ...
'               USA ', ...
'               Telephone: (818) 354-8032', ...
'         Electronic Mail Address:INTERNET > johan@podaac.jpl.nasa.gov');


Comments = [Comments1 Comments2 Comments3];
