% How to add the trenberth wind stress data.  You gave me a URL
% so for my zeroth order archive.m file I type this:
GetFunctionName = 'getrectg';
Server = 'http://ferret.pmel.noaa.gov/cgi-bin/dods/nph-dods/data/PMEL/large_trenberth_moncl.nc';
	  
LonRange = [-180 180];
LatRange = [-90 90];
TimeRange = [1800.0 2000.0];
DepthRange = [0.0 0.0];
Resolution = NaN;
DataName = 'Trenberth Wind Stress - PMEL';

SelectableVariables = str2mat('Wind Stress U', 'Wind Stress V');

% Next I get the DAS using loaddods.
%DAS =loaddods('-A','http://ferret.pmel.noaa.gov/cgi-bin/dods/nph-dods/data/PMEL/large_trenberth_moncl.nc');  
% and I see that there is a TAUX and a TAUY, so those must
% be the names for the stresses.

% first order: looked at toplevel of .das using loadods
DodsName = str2mat('TAUX', 'TAUY');

% Now ^B in the gui to get the bookmarks editor.  select a wind
% dataset ^C ^V to copy and paste it. ^I to bring up the
% properties editor for the copied entry.  I pick a new color
% (green), erase the name and the archive, and type
% in 'trenberth' for the new archive.  'Apply' these changes,
% then hit 'Reload/clear' to force the old metadata to be
% purged and for this file, trenberth.m to be parsed.  The
% dataset name is automagically filled in.

% click ok to dismiss the properties editor, then back in
% the bookmarks editor ^S to save (and apply to GUI) and close.

% Second order: selected the entire time range and did a get
%details request. Prompted to select axis mappings but they
% are fairly obvious.  I then got this URL in response (in the
% URLlist. So clearly this is a climatology:

%http://ferret.pmel.noaa.gov/cgi-bin/dods/nph-dods/data/PMEL/large_trenberth_moncl.nc?TAUX[0:1:11][0:1:72][0:1:143],TAUY[0:1:11][0:1:72][0:1:143]

% I still don't know the resolution or actual geographic extent,
% but I can now fill in the TimeRange a bit better.  So I
% substitute the following line for the original time range guess:

TimeRange = [1800 str2num(datestr(date,10))];

% ^B to bring up the bookmarks editor, select trenberth, ^I to
% get the properties editor, Press Reload/clear, then Ok to
% dismiss this window, ^S to save the bookmarks and apply them
%to the GUI again.

% Now I select June 1947 and Wind Stress U and V and do a get
% details.  Must identify the axes again because reloading the
% archive cleared the cached metadata.  I see that the time slice
% which is selected in the URL:

% 'http://ferret.pmel.noaa.gov/cgi-bin/dods/nph-dods/data/PMEL/large_trenberth_moncl.nc?TAUX[5:1:5][0:1:72][0:1:143],TAUY[5:1:5][0:1:72][0:1:143]'

% is [5:1:5] which means the time axis mapping is fine and I don't
% need to manually add any kind of offset or anything (which would
% be very unusual for a climatology).

% Do a get data, and go with the default plot options.  I see
% immediately that the extent of the dataset is indeed global.
% Now to figure out the resolution.

%>> diff(R1_Latitude)
% gives me 2.5, as does diff(R1_Longitude).

Resolution = 2.5*111; % in km

% ^B, get the editor, ^I get the properties, 'Reload/Clear' one
% more time, dismiss the properties, ^S, save and close ....
% Select 'Trenberth Wind Stress in the GUI again, reselect 
% June 1947, and this time, a Resolution of 555.0 km.  Do
% a 'Get Data', re-identify the axes one last time when prompted,
% and change the quiver plot color to 'r' (red).  Over plotting
% on last plot, and yes, the scaling is now different but I
% clearly have every other data point and they are also clearly
% one per 5 degrees, so it's all done.

% you can execute this file as-is, because my first guesses at
% the top will simply be over-written by the later values lower
% down.

% The only thing missing is the documentation, but you didn't give
% me a URL for that.  However, if you had, I would finally add:

Comments = sprintf('%s\n', ...
'          A Global Ocean Wind Stress Climatology Based on ECMWF Analyses ',...
' ',...
'The ECMWF analyses for 1980-1989 were used to derive a global year-month ',...
'wind stress climatology; several climate monthly mean grids were also formed.',...
' ',...
'The following is taken from the reference below: ',...
' ',...
'Computations of the surface wind stress over the global oceans have been made ',...
'using surface winds from the European Centre for Medium Range Weather ',...
'Forecasts (ECMWF) for seven years [Note: updated to 10 years].  The drag ',...
'coefficient is a function of wind speed and atmospheric stability, and the ',...
'density is computed for each observation.',...
' ',...
' ',...
'Reference: ',...
' ',...
'Trenberth, Olsen, and Large, 1989: A global ocean wind stress climatology ',... 
'based on ECMWF analyses. NCAR Tech. Note NCAR/TN-338+str, 93pp.');

% cheers,

%          Deirdre    2004/04/17
