function makemanifest

% MAKEMANIFEST: Part of the NVODS Matlab GUI.  This developer
% function will create a new MANIFEST based on all the files
% in the DATASETS directory, or on all the datasets in the
% bookmarks file.

% USAGE MAKEMANIFEST

% dbyrne@umeoce.maine.edu, 2003/12/05

% set up default output
% Get separator for directory structure.
dirsep = '/';
c = computer;
if strcmp(c(1:2),'PC')
  dirsep = '\';
elseif strcmp(c(1:2),'MA')
  dirsep = ':';
end

dodsdirnq = which('browse');
dodsdirnq = dodsdirnq(1:max(findstr(dodsdirnq,dirsep)));
dodsdatadirnq = [dodsdirnq 'DATASETS' dirsep];

% get the list of .m files:
w = what(dodsdatadirnq);
w = w.m;
   
% FOR TESTING
%w = w([1 29 30 34 45:51 52 56:58 93]);

list = struct([]);
for i = 1:length(w)
  [funlist, junk, junk, junk, vars] = depfun(w{i},'-toponly');
  v = cell(size(vars));
  if ~isempty(vars)
    [v{:}] = deal(vars(:).name);
  end
  list(i).funs = funlist;
  if strmatch('GetFunctionName', v)
    % this is an archive.  Save its dependent functions
    % and evaluate it to get some others
    eval(w{i}(1:size(w{i},2)-2))
    s = which(GetFunctionName);
    list(i).funs = cellstr(char(list(i).funs{:}, s));
    if strmatch('Cat_m_File', v)
      s = which(Cat_m_File);
      list(i).funs = cellstr(char(list(i).funs{:}, s));
    end
    if strmatch('CanOrbFile', v)
      s = which(CanOrbFile);
      list(i).funs = cellstr(char(list(i).funs{:}, s));
    end
    if strmatch('AdditionalFunctions', v)
      for j = 1:size(AdditionalFunctions,1)
	s = which(deblank(AdditionalFunctions(j,:)));
	list(i).funs = cellstr(char(list(i).funs{:}, s));
      end
    end
  end
end

list = list(:);
funnames = '';
keep = ones(length(w),1);

% strip to just those functions within the DODS data directory
% as these are the only ones we can 'update'
for i = 1:length(w)
  j = strmatch(dodsdatadirnq, list(i).funs);
  list(i).funs = list(i).funs(j);
  toplist(i) = list(i).funs(1);
end

% now loop through and append subsidiary functions
clear j
for i = 1:length(w)
  s1 = length(list(i).funs);
  j(:,1) = [2 s1]';
  len = size(j,2);
  while j(1, len) <= j(2, len)
    if sum(strcmp(list(i).funs(j(1, len)), toplist)) > 0
      k = find(strcmp(list(i).funs(j(1, len)), toplist));
      keep(k) = 0;
      s2 = length(list(k).funs);
      if s2 >= 2
	% we have a match AND some things to add to the list
	list(i).funs = [list(i).funs; list(k).funs(2:s2)];
	j = [j [s1+1 nan]'];
	len = size(j,2);
	s1 = length(list(i).funs);
	j(2, len) = s1;
      else
	% we had a match but no subsidiary functions to add
	% back up one level
	len = size(j,2);
	j(1, len) = j(1, len)+1;
	while j(1, len) > j(2, len)
	  j = j(:, 1:len-1);
	  len = size(j,2);
	  if len == 0
	    break
	  else
	    j(1, len) = j(1, len)+1;
	  end
	end
      end
    else
      % no match -- increment current j
      len = size(j,2);
      j(1, len) = j(1, len)+1;
      while j(1, len) > j(2, len)
	j = j(:, 1:len-1);
	len = size(j,2);
	if len == 0
	  break
	else
	  j(1, len) = j(1, len)+1;
	end
      end
    end   
    if len == 0
      break
    end
  end
end

% strip to only toplevel functions
list = list(find(keep));
   
% now write a new MANIFEST
fid = fopen([dodsdatadirnq 'MANIFEST.new'],'w');
if fid > -1
  fprintf(fid, '%s\n','%');
  fprintf(fid, '%s %s\n', '% This is the NVODS MATLAB GUI MANIFEST', ...
	  date);
  fprintf(fid, '%s\n','%');
  fprintf(fid, '%s\n','%');
  fprintf(fid, '%s\n', ['% Each line below represents a dataset', ...
		    ' to be made available in the']);
  fprintf(fid, '%s\n', ['% browser. The first name on the line' ...
		    ' indicates the "archive.m" file']);
  
  fprintf(fid, '%s\n', ['% corresponding to the given dataset. The' ...
		    ' full name of the data set']);
  
  fprintf(fid, '%s\n', ['% will be found within that file. The other' ...
		    ' names on the line indicate']);
  
  fprintf(fid, '%s\n', ['% matlab .m files needed by that particular dataset.']);
  fprintf(fid, '%s\n','%');
  fprintf(fid, '%s\n', ['% Both this manifest file and all the files' ...
		    ' indicated below should']);
  
  fprintf(fid, '%s\n', ['% reside in the DATASETS sub-directory of' ...
		    ' the NVODS Matlab GUI.']);
  fprintf(fid, '%s\n','%');
  fprintf(fid, '%s\n', ['% All the datasets indicated in this file' ...
		    ' exist on the central NVODS']);
  fprintf(fid, '%s\n', ['% server. Do not edit this file, since it' ...
		    ' is automatically generated.']);
  fprintf(fid, '%s','%');
  
  for i = 1:length(list)
    % strip out duplicates
    funs = list(i).funs;
    j = 1; s1 = length(funs);
    while j <= s1
      s2 = size(funs{j},2);
      q = strncmp(funs{j}, funs, s2);
      q(j) = 0;
      if sum(q) > 0 
	funs = funs(find(~q));
	s1 = s1-sum(q);
      end
      j=j+1;
    end
    list(i).funs = funs;
    
    % write output to file
    for j = 1:length(list(i).funs)
      % strip off directory and '.m' suffix
      s1 = max(findstr(dirsep, list(i).funs{j}))+1;
      s2 = length(list(i).funs{j})-2;
      str = list(i).funs{j}(s1:s2);
      if j == 1
	fprintf(fid, '\n%s ', str);
      else
	fprintf(fid, '%s ', str);
      end
    end
  end
  fprintf(fid,'\n');
  fclose(fid);
end

return
