function varargout=dodsweb(html_file)

% DODSWEB Open Web browser on site or files for the NVODS Matlab GUI.
%
%   DODSWEB URL displays the specified URL (Uniform Resource Locator) in
%   in the desktop Help Browser window.
%
%   STAT = WEB(...) returns the status of the WEB command in the variable
%   STAT. STAT = 0 indicates successful execution. STAT = 1 indicates that
%   the browser was not found.
%
%   Examples:
%      web file:///disk/dir1/dir2/foo.html
%         opens the file foo.html in your browser.
%
%      web(['file:///' which('foo.html')]);
%         opens the file foo.html if it is on the MATLAB path.
%
%      web http://www.mathworks.com
%         loads The MathWorks Web page into your browser.
%
%      web mailto:email_address
%         uses your browser to send mail.
%
%   Significantly modified to handle Netscape version 7.0 and higher.
%   by dbyrne@umeoce.maine.edu, 2003/05/13


% Initialize error status.
stat = 0;

% If no argument is specified, complain and exit.
if nargin==0
   error('No URL specified.');
   if nargout > 0
      varargout(1) = {stat};
   end;
   return;
end

% If in Desktop environment, and only URL argument specified, use ICE Browser.
% Except for "mailto:", which is not supported in ICE.
if nargin==1 & (usejava('mwt') == 1) & ~strncmp(html_file,'mailto:',7)
   hBrowser = com.mathworks.ide.help.HelpBrowser.getHelpBrowser;
   % If no protocol specified, or an absolute/UNC pathname is not given, 
   % include explicit 'http:'.  Otherwise ICE assumes 'file:'
   if isempty(findstr(html_file,':')) & ~strcmp(html_file(1:2),'\\') & ~strcmp(html_file(1),'/') 
      html_file = ['http://' html_file];
   end
   setCurrentLocation(hBrowser, html_file);
   if nargout > 0
      varargout(1) = {stat};  
   end;
   return;
end
% determine what computer we're on
if (~isunix & ~ispc)
    error(['WEB not available for this architecture: ', computer, '.'])
end

% get options
[doccmd,options] = docopt;

% open HTML file in browser
if isunix
   % The unix command has a bunch of problems when we try to handle errors.
   % Assume we submit to unix:
   %
   %    Mosiac file &
   %
   %    1. We don't know what shell is being used. It depends on the platform.
   %    2. The unix command does not save stderr
   %    3. You cannot save output since this blocks the return of the MATLAB
   %    prompt.
   %    4. You will always get the pid message and if there is a error message
   %    it will be cryptic one from the system.
   %    5. Status is always successful.
   %
   % Because of the above problems, there is no error handling. The user
   % will have to figure out things from the system error message.

   % separate the path from the filename for netscape
   [dirx,fname,extx]=fileparts(doccmd);

   if strmatch(fname, strvcat('netscape', 'Netscape'))
     comm = [doccmd ' ' options ' -remote "openURL(' html_file ')"'];
     [stat, result] = unix(comm);
     if ~isempty(findstr(result, 'No running window'))
       comm = [doccmd ' ' options ' ' html_file ' >& /dev/null &' ];
       [stat, result] = unix(comm);
     end
   else
      % Mosaic or Arena must be the browser can not look for netscape lock file
      % To the best of my knowledge Mosaic & Arena don't support -remote  bmb
      % so just start a new session
      comm = [doccmd ' ' options ' ' html_file ' >& /dev/null &' ];
      [stat, result] = unix(comm);
   end

elseif ispc
   stat = ibrowse(html_file);
end

if nargout > 0
   varargout(1) = {stat};
end;

