function  [lontest] = get_lon_rng(ranges, lonmin, lonmax);
%
% This function will find those data sets that are out of range in longitude.
%
%  Input: ranges - the range selected in the browse window
%         (lonmin,lonmax) - the range of the data set.
%         datamin - 1 if the range selected is below the data set range
%         datamax - 1 if the range selected is above the data set range
% For simplicity I have set both datamax and datamin to either 0 if the
% data set falls in the selected range or 1 if out of the range.
%
%   lonmin,lonax
%
%       -180                        0                    180
%  1      |       xxxx                                    |
%  2      |                      xxxxxxxx                 |
%  3      |                                xxxxx          |
%  4      |xxxx                                       xxxx|
%  5      |xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx|
%
%   ranges
%
%       -180                        0                    180
%  A      |       xxxx                                    |
%  B      |                      xxxxxxxx                 |
%  C      |                                xxxxx          |
%  D      |xxxx                                       xxxx|
%  E      |xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx|
%
%
%  Special cases 
%
%      lonmax < lonmin      case 4 \   If both are true there is overlap.
%      ranges(1,2) < ranges(1,1)  case D /
%      abs(lonmax - lonmin) = 360     case 5 No other tests, always overlap.
%
% Case 5 - Dataset covers 360 degrees so always overlaps. 
if abs(lonmax - lonmin) > 359.999
  lontest = 0;
else
  % Case 4 - Dataset wraps around 180
  if lonmax < lonmin
    % Case D - Selected range wraps around 180
    if ranges(1,2) < ranges(1,1)
      lontest = 0;
    else
      if (ranges(1,1) > lonmax) & (ranges(1,2) < lonmin) 
        lontest = 1;
      else
        lontest = 0;
      end
    end
  else
    % lonmax > lonmin
    % Case 1-3, D 
    if ranges(1,2) < ranges(1,1)
      if (ranges(1,2) < lonmin) & (ranges(1,1) > lonmax)
        lontest = 1;
      else
        lontest = 0;
      end
    else
      if (ranges(1,2) < lonmin) | (ranges(1,1) > lonmax) 
        lontest = 1;
      else
        lontest = 0;
      end
    end
  end
end
return
