function [argout1, argout2, argout3] = strsearch(arg1, arg2, arg3, arg4)

% STRSEARCH Controls the 'Find' window in the NVODS Matlab GUI.
%
% Deirdre Byrne, dbyrne@umeoce.maine.edu

% determined externally
global dodsdir dirsep user_variables userlist dset var
global brs_old_var brs_old_dset
global folder_start folder_end

% used locally
global SEARCH_FIGURE SEARCH_BUTTONS SEARCH_LOC SEARCH_STRING

switch arg1
  case 'casesense'
   if get(SEARCH_BUTTONS(8),'value') == 1
     set(SEARCH_BUTTONS(8),'fontweight','bold')
   else
     set(SEARCH_BUTTONS(8),'fontweight','normal')
   end
  
  case 'changecolor'
    if ~isempty(findfig('NVODS search'))
      foregroundcolor = arg2(1,:);
      backgroundcolor = arg2(2,:);
      editcolor = arg2(3,:);
      set(SEARCH_FIGURE, 'color', backgroundcolor)
      set(SEARCH_BUTTONS,'backgroundcolor',backgroundcolor)
      set(SEARCH_BUTTONS(3),'backgroundcolor',editcolor)
      set(SEARCH_BUTTONS,'foregroundcolor',foregroundcolor)
    end
    
  case 'direction'
   if get(SEARCH_BUTTONS(9),'value') == 1
     set(SEARCH_BUTTONS(9),'fontweight','bold')
   else
     set(SEARCH_BUTTONS(9),'fontweight','normal')
   end
    
  case 'fclose'
    % close the figure
    set(SEARCH_FIGURE,'visible','off');
    
  case 'find'
    % get the string
    SEARCH_STRING = get(SEARCH_BUTTONS(3),'string');
    if isempty(deblank(SEARCH_STRING))
      return
    end
    
    % get the search locale
    findin = get(SEARCH_BUTTONS(5),'value');
    if findin == 0, findin = 1; end
    
    % get the Case Sensitivity
    cs = get(SEARCH_BUTTONS(8),'value');
    
    % get the direction
    direction = get(SEARCH_BUTTONS(9),'value');
    if findin == 1
      % searching in dataset names
      l = length(userlist);
      X = ~(isfolder(userlist,1:l) | isendfolder(userlist,1:l));
      k = find(X); % find only dataset listings -- not folder marks
      namelist = char(userlist(k).name);
      l = length(namelist);
      if ~cs % no case sensitivity
	namelist = lower(namelist);
	SEARCH_STRING = lower(SEARCH_STRING);
      end
      pos = nan;
      hloc = dscrolllist('getpos');
      if ~direction % find forwards
	if hloc > 0
	  if any(k == hloc), m = find(hloc == k);
	  else, m = min(find(k > hloc))-1;
	  end
	else
	  m = 0;
	end
	for i = m+1:l
	  if strfind(namelist(i,:),SEARCH_STRING);
	    pos = i;
	    break
	  end
	end
      else % find backwards
	if hloc > 0
	  if any(k == hloc), m = find(hloc == k);
	  else, m = max(find(k < hloc))+1;
	  end
	else
	  m = l+1;
	end
	for i = m-1:-1:1
	  if strfind(namelist(i,:),SEARCH_STRING);
	    pos = i;
	    break
	  end
	end
      end
      
      % the consequences
      if ~isnan(pos)
	pos = k(pos);
	dscrolllist('setpos',pos)
      end

    elseif findin == 2
      % searching in dataset descriptions -- this would be improved
      % if those were cached in the userlist!
      l = length(userlist);
      X = ~(isfolder(userlist,1:l) | isendfolder(userlist,1:l));
      k = find(X); % find only dataset listings -- not folder marks
      archlist = char(userlist(k).archive);
      l = length(archlist);
      if ~cs % no case sensitivity
	SEARCH_STRING = lower(SEARCH_STRING);
      end
      pos = nan;
      hloc = dscrolllist('getpos');
      if ~direction % find forwards
	if hloc > 0
	  if any(k == hloc), m = find(hloc == k);
	  else, m = min(find(k > hloc))-1;
	  end
	else
	  m = 0;
	end
	for i = m+1:l
	  arch = deblank(archlist(i,:));
	  if ~checkfunction(arch)
	    eval(arch)
	    if ~cs % no case sensitivity
	      Comments = lower(Comments);
	    end
	    for j = 1:size(Comments,1)
	      if strfind(Comments(j,:),SEARCH_STRING);
		pos = i;
		break
	      end
	    end
	    if ~isnan(pos)
	      break
	    end
	  end
	end
      else % find backwards
	if hloc > 0
	  if any(k == hloc), m = find(hloc == k);
	  else, m = max(find(k < hloc))+1;
	  end
	else
	  m = l+1;
	end
	for i = m-1:-1:1
	  arch = deblank(archlist(i,:));
	  if ~checkfunction(arch)
	    eval(arch)
	    if ~cs % no case sensitivity
	      Comments = lower(Comments);
	    end
	    for j = 1:size(Comments,1)
	      if strfind(Comments(j,:),SEARCH_STRING);
		pos = i;
		break
	      end
	    end
	    if ~isnan(pos)
	      break
	    end
	  end
	end
      end
      
      % the consequences
      if ~isnan(pos)
	pos = k(pos);
	dscrolllist('setpos',pos)
	view = browse('getview');
	if strcmp(view,'plot')
	  browse('swapview')
	end
      end

    elseif findin == 3
      % searching in variables list
      uservarlist = user_variables;
      l = length(user_variables);
      if ~cs % no case sensitivity
	uservarlist = lower(uservarlist);
	SEARCH_STRING = lower(SEARCH_STRING);
      end
      
      if ~direction % find fowards
	if ~isnan(var);
	  m = max(var);
	else
	  m = 0;
	end
	for i = m+1:l
	  if strfind(uservarlist(i,:),SEARCH_STRING);
	    brs_old_var = var;
	    var = i;
	    break
	  end
	end
      else
	if ~isnan(var);
	  m = min(var);
	else
	  m = l+1;
	end
	for i = m-1:-1:1
	  if strfind(uservarlist(i,:),SEARCH_STRING);
	    brs_old_var = var;
	    var = i;
	    break
	  end
	end
      end
      if ~isnan(var)
	% not clear what to do next?  Do we SELECT these
	% variables?  Do we show all of them, or merely the
	% first match?
	vscrolllist('setpos',var)
      end
      
    elseif findin == 4
      % searching in dataset acknowledgements -- this would be improved
      % if those were cached in the userlist!
      l = length(userlist);
      X = ~(isfolder(userlist,1:l) | isendfolder(userlist,1:l));
      k = find(X); % find only dataset listings -- not folder marks
      archlist = char(userlist(k).archive);
      l = length(archlist);
      if ~cs % no case sensitivity
	SEARCH_STRING = lower(SEARCH_STRING);
      end
      pos = nan;
      hloc = dscrolllist('getpos');
      if ~direction % find forwards
	if hloc > 0
	  if any(k == hloc), m = find(hloc == k);
	  else, m = min(find(k > hloc))-1;
	  end
	else
	  m = 0;
	end
	for i = m+1:l
	  arch = deblank(archlist(i,:));
	  if ~checkfunction(arch)
	    eval(arch)
	    if ~cs % no case sensitivity
	      Acknowledge = lower(Acknowledge);
	    end
	    for j = 1:size(Acknowledge,1)
	      if strfind(Acknowledge(j,:),SEARCH_STRING);
		pos = i;
		break
	      end
	    end
	    if ~isnan(pos)
	      break
	    end
	  end
	end
      else % find backwards
	if hloc > 0
	  if any(k == hloc), m = find(hloc == k);
	  else, m = max(find(k < hloc))+1;
	  end
	else
	  m = l+1;
	end
	for i = m-1:-1:1
	  arch = deblank(archlist(i,:));
	  if ~checkfunction(arch)
	    eval(arch)
	    if ~cs % no case sensitivity
	      Acknowledge = lower(Acknowledge);
	    end
	    for j = 1:size(Acknowledge,1)
	      if strfind(Acknowledge(j,:),SEARCH_STRING);
		pos = i;
		break
	      end
	    end
	    if ~isnan(pos)
	      break
	    end
	  end
	end
      end
      
      % the consequences
      if ~isnan(pos)
	pos = k(pos);
	dscrolllist('setpos',pos)
	view = browse('getview');
	if strcmp(view,'plot')
	  browse('swapview')
	end
      end

    end
  case 'fontsize'
    if ~isempty(findfig('NVODS search'))
      fontsize = arg2;
      % change fonts
      set(SEARCH_BUTTONS,'fontsize',fontsize)
    end

  case 'getfigpos'
    argout1 = zeros(1,4);
    if isempty(findfig('NVODS search'))
      return
    end
    % edit figure
    un = get(SEARCH_FIGURE, 'units');
    set(SEARCH_FIGURE, 'units', 'pixels');
    figpos = get(SEARCH_FIGURE, 'pos');
    set(SEARCH_FIGURE,'units', un);
    argout1 = figpos;
    
  case 'showfig'
    if isempty(findfig('NVODS search'))
      fontsize = 0;
      colors = zeros(1,3);
      figsizes = zeros(1,4);
      % set up the dataset/folder properties editing windows
      strsearch('start', fontsize, colors, figsizes)
    end
    figure(SEARCH_FIGURE)
    
  case 'start'
    % close any existing of these figures
    closefig('NVODS search')

    % set fontsize
    fontsize = arg2;
    if fontsize == 0
      fontsize = browse('getfontsize');
    end

    % set colors
    colors = arg3;
    if all(colors == 0)
      colors = browse('getcolors');
      colors = colors([6 1 5],:);
    end
    foregroundcolor = colors(1,:);
    backgroundcolor = colors(2,:);
    editcolor = colors(3,:);
    
    % set figure positions
    figpos = arg4(1,:);
    
    % THE SEARCH FIGURE
    if any(figpos(3:4) == 0)
      figpos = browse('figpos',9);
    end
    
    if any(figpos(3:4) == 0)
      browse_fig = browse('getfigno');
      un = get(browse_fig,'units');
      set(browse_fig,'units','pixels');
      b_offset = get(browse_fig,'pos');
      set(browse_fig,'units',un)
      fig_size = [400 150];
      fig_offset = [b_offset(1)-5 ...
	    b_offset(2)-5];
      figpos = [fig_offset fig_size];
    end

    SEARCH_FIGURE = figure('menubar','none','visible','off', ...
	'units', 'pixels', 'pos', figpos, ...
	'numbertitle', 'off','name', 'NVODS Find', ...
	'resize','on', 'userdata', 'NVODS search', ...
	'color', backgroundcolor);

    % set up file menu options  
    filemenu = uimenu(SEARCH_FIGURE,'label','File');
    fileopts(1) = uimenu(filemenu,'label','Close', ...
	'callback','strsearch(''fclose'')');

    % set up the figure
    SEARCH_BUTTONS(1) = uicontrol('parent',SEARCH_FIGURE, ...
	'style','frame', ...
	'units', 'pixels', ...
	'position',[0 50 400 100], ...
	'backgroundcolor',backgroundcolor, ...
	'fontsize', fontsize);
    SEARCH_BUTTONS(2) = uicontrol('parent',SEARCH_FIGURE, ...
	'style','text', ...
	'horiz','left', ...
	'fontweight','bold', ...
	'units', 'pixels', ...
	'position',[5 115 45 20], ...
	'foregroundcolor',foregroundcolor, ...
	'backgroundcolor',backgroundcolor, ...
	'string', 'Find:', ...
	'fontsize', fontsize);
    SEARCH_BUTTONS(3) = uicontrol('parent',SEARCH_FIGURE, ...
	'style','edit', ...
	'horiz','left', ...
	'units', 'pixels', ...
	'position',[55 110 340 30], ...
	'foregroundcolor',foregroundcolor, ...
	'backgroundcolor',editcolor, ...
	'string', '', ...
	'fontsize', fontsize);
    SEARCH_BUTTONS(4) = uicontrol('parent',SEARCH_FIGURE, ...
	'style','text', ...
	'horiz','left', ...
	'fontweight','bold', ...
	'units', 'pixels', ...
	'position',[5 70 70 20], ...
	'foregroundcolor',foregroundcolor, ...
	'backgroundcolor',backgroundcolor, ...
	'string', 'Find in:', ...
	'fontsize', fontsize);
    SEARCH_BUTTONS(5) = uicontrol('parent',SEARCH_FIGURE, ...
	'style','popupmenu', ...
	'horiz','left', ...
	'units', 'pixels', ...
	'position',[75 65 200 30], ...
	'foregroundcolor',foregroundcolor, ...
	'backgroundcolor',backgroundcolor, ...
	'string', ['Dataset Names | Dataset ', ...
	   'Descriptions | Variables | Acknowledgements'], ...
	'fontsize', fontsize);
    SEARCH_BUTTONS(6) = uicontrol('parent',SEARCH_FIGURE, ...
	'style','frame', ...
	'units', 'pixels', ...
	'position',[0 0 400 50], ...
	'backgroundcolor',backgroundcolor, ...
	'fontsize', fontsize);
    SEARCH_BUTTONS(7) = uicontrol('parent',SEARCH_FIGURE, ...
	'style','push', ...
	'horiz','center', ...
	'fontweight','bold', ...
	'units', 'pixels', ...
	'position',[5 10 70 30], ...
	'foregroundcolor',foregroundcolor, ...
	'backgroundcolor',backgroundcolor, ...
	'string', 'Find Next', ...
        'callback','strsearch(''find'')', ....
	'fontsize', fontsize);
    SEARCH_BUTTONS(8) = uicontrol('parent',SEARCH_FIGURE, ...
	'style','toggle', ...
	'horiz','center', ...
	'fontweight','normal', ...
	'units', 'pixels', ...
	'position',[95 10 135 30], ...
	'foregroundcolor',foregroundcolor, ...
	'backgroundcolor',backgroundcolor, ...
	'string', 'Case Sensitive', ...
        'callback', 'strsearch(''casesense'')', ...				  
	'fontsize', fontsize);
    SEARCH_BUTTONS(9) = uicontrol('parent',SEARCH_FIGURE, ...
	'style','toggle', ...
	'horiz','center', ...
	'fontweight','normal', ...
	'units', 'pixels', ...
	'position',[240 10 150 30], ...
	'foregroundcolor',foregroundcolor, ...
	'backgroundcolor',backgroundcolor, ...
	'string', 'Search Backwards', ...
        'value', 0, ...
        'callback', 'strsearch(''direction'')', ...
	'fontsize', fontsize);
    % REVEAL THE FIGURE
    set(SEARCH_FIGURE,'vis','on')
end

return